summaryrefslogtreecommitdiff
path: root/indra/newview
diff options
context:
space:
mode:
authorAndrey Kleshchev <andreykproductengine@lindenlab.com>2023-02-20 22:24:46 +0200
committerAndrey Kleshchev <andreykproductengine@lindenlab.com>2023-02-21 00:24:23 +0200
commit6a260bb3f0bc5bf726ad1c3f98e39d3fb9679484 (patch)
tree1a54500e9681104e87eb33b5d7b4e740af69ab79 /indra/newview
parente40f9af831c1257dea37a4565aafd73baa5005b6 (diff)
SL-19108 Rename outfit snapshot floater
Diffstat (limited to 'indra/newview')
-rw-r--r--indra/newview/CMakeLists.txt4
-rw-r--r--indra/newview/llappviewer.cpp4
-rw-r--r--indra/newview/llfloatersimplesnapshot.cpp (renamed from indra/newview/llfloatersimpleoutfitsnapshot.cpp)75
-rw-r--r--indra/newview/llfloatersimplesnapshot.h (renamed from indra/newview/llfloatersimpleoutfitsnapshot.h)41
-rw-r--r--indra/newview/lloutfitgallery.cpp4
-rw-r--r--indra/newview/llviewerfloaterreg.cpp4
-rw-r--r--indra/newview/llviewermenufile.cpp6
-rw-r--r--indra/newview/skins/default/xui/en/floater_simple_snapshot.xml (renamed from indra/newview/skins/default/xui/en/floater_simple_outfit_snapshot.xml)2
8 files changed, 71 insertions, 69 deletions
diff --git a/indra/newview/CMakeLists.txt b/indra/newview/CMakeLists.txt
index c570052908..08cce23852 100644
--- a/indra/newview/CMakeLists.txt
+++ b/indra/newview/CMakeLists.txt
@@ -290,7 +290,7 @@ set(viewer_SOURCE_FILES
llfloateroutfitphotopreview.cpp
llfloaterobjectweights.cpp
llfloateropenobject.cpp
- llfloatersimpleoutfitsnapshot.cpp
+ llfloatersimplesnapshot.cpp
llfloaterpathfindingcharacters.cpp
llfloaterpathfindingconsole.cpp
llfloaterpathfindinglinksets.cpp
@@ -934,7 +934,7 @@ set(viewer_HEADER_FILES
llfloateroutfitphotopreview.h
llfloaterobjectweights.h
llfloateropenobject.h
- llfloatersimpleoutfitsnapshot.h
+ llfloatersimplesnapshot.h
llfloaterpathfindingcharacters.h
llfloaterpathfindingconsole.h
llfloaterpathfindinglinksets.h
diff --git a/indra/newview/llappviewer.cpp b/indra/newview/llappviewer.cpp
index dc9f7bb403..0f419d8243 100644
--- a/indra/newview/llappviewer.cpp
+++ b/indra/newview/llappviewer.cpp
@@ -213,7 +213,7 @@
#include "llcommandlineparser.h"
#include "llfloatermemleak.h"
#include "llfloaterreg.h"
-#include "llfloatersimpleoutfitsnapshot.h"
+#include "llfloatersimplesnapshot.h"
#include "llfloatersnapshot.h"
#include "llsidepanelinventory.h"
#include "llatmosphere.h"
@@ -1525,7 +1525,7 @@ bool LLAppViewer::doFrame()
LL_PROFILE_ZONE_NAMED_CATEGORY_APP( "df Snapshot" )
pingMainloopTimeout("Main:Snapshot");
LLFloaterSnapshot::update(); // take snapshots
- LLFloaterSimpleOutfitSnapshot::update();
+ LLFloaterSimpleSnapshot::update();
gGLActive = FALSE;
}
}
diff --git a/indra/newview/lloutfitgallery.cpp b/indra/newview/lloutfitgallery.cpp
index 602b7412a4..ce1330dfe1 100644
--- a/indra/newview/lloutfitgallery.cpp
+++ b/indra/newview/lloutfitgallery.cpp
@@ -41,7 +41,7 @@
#include "llfilepicker.h"
#include "llfloaterperms.h"
#include "llfloaterreg.h"
-#include "llfloatersimpleoutfitsnapshot.h"
+#include "llfloatersimplesnapshot.h"
#include "llimagedimensionsinfo.h"
#include "llinventoryfunctions.h"
#include "llinventorymodel.h"
@@ -1387,7 +1387,7 @@ void LLOutfitGallery::onSelectPhoto(LLUUID selected_outfit_id)
void LLOutfitGallery::onTakeSnapshot(LLUUID selected_outfit_id)
{
LLFloaterReg::toggleInstanceOrBringToFront("simple_outfit_snapshot");
- LLFloaterSimpleOutfitSnapshot* snapshot_floater = LLFloaterSimpleOutfitSnapshot::getInstance();
+ LLFloaterSimpleSnapshot* snapshot_floater = LLFloaterSimpleSnapshot::getInstance();
if (snapshot_floater)
{
snapshot_floater->setOutfitID(selected_outfit_id);
diff --git a/indra/newview/llviewerfloaterreg.cpp b/indra/newview/llviewerfloaterreg.cpp
index 06fba187bb..4d51d56569 100644
--- a/indra/newview/llviewerfloaterreg.cpp
+++ b/indra/newview/llviewerfloaterreg.cpp
@@ -104,7 +104,7 @@
#include "llfloaterobjectweights.h"
#include "llfloateropenobject.h"
#include "llfloateroutfitphotopreview.h"
-#include "llfloatersimpleoutfitsnapshot.h"
+#include "llfloatersimplesnapshot.h"
#include "llfloaterpathfindingcharacters.h"
#include "llfloaterpathfindingconsole.h"
#include "llfloaterpathfindinglinksets.h"
@@ -469,7 +469,7 @@ void LLViewerFloaterReg::registerFloaters()
LLFloaterReg::add("scene_load_stats", "floater_scene_load_stats.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterSceneLoadStats>);
LLFloaterReg::add("stop_queue", "floater_script_queue.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterNotRunQueue>);
LLFloaterReg::add("snapshot", "floater_snapshot.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterSnapshot>);
- LLFloaterReg::add("simple_outfit_snapshot", "floater_simple_outfit_snapshot.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterSimpleOutfitSnapshot>);
+ LLFloaterReg::add("simple_snapshot", "floater_simple_snapshot.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterSimpleSnapshot>);
LLFloaterReg::add("search", "floater_search.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterSearch>);
LLFloaterReg::add("profile", "floater_profile.xml",(LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterProfile>);
LLFloaterReg::add("guidebook", "floater_how_to.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterHowTo>);
diff --git a/indra/newview/llviewermenufile.cpp b/indra/newview/llviewermenufile.cpp
index fdf1d04c09..ab8ec8a288 100644
--- a/indra/newview/llviewermenufile.cpp
+++ b/indra/newview/llviewermenufile.cpp
@@ -38,7 +38,7 @@
#include "llfloatermap.h"
#include "llfloatermodelpreview.h"
#include "llfloatersnapshot.h"
-#include "llfloatersimpleoutfitsnapshot.h"
+#include "llfloatersimplesnapshot.h"
#include "llimage.h"
#include "llimagebmp.h"
#include "llimagepng.h"
@@ -664,7 +664,7 @@ class LLFileEnableCloseAllWindows : public view_listener_t
bool handleEvent(const LLSD& userdata)
{
LLFloaterSnapshot* floater_snapshot = LLFloaterSnapshot::findInstance();
- LLFloaterSimpleOutfitSnapshot* floater_outfit_snapshot = LLFloaterSimpleOutfitSnapshot::findInstance();
+ LLFloaterSimpleSnapshot* floater_outfit_snapshot = LLFloaterSimpleSnapshot::findInstance();
bool is_floaters_snapshot_opened = (floater_snapshot && floater_snapshot->isInVisibleChain())
|| (floater_outfit_snapshot && floater_outfit_snapshot->isInVisibleChain());
bool open_children = gFloaterView->allChildrenClosed() && !is_floaters_snapshot_opened;
@@ -681,7 +681,7 @@ class LLFileCloseAllWindows : public view_listener_t
LLFloaterSnapshot* floater_snapshot = LLFloaterSnapshot::findInstance();
if (floater_snapshot)
floater_snapshot->closeFloater(app_quitting);
- LLFloaterSimpleOutfitSnapshot* floater_outfit_snapshot = LLFloaterSimpleOutfitSnapshot::findInstance();
+ LLFloaterSimpleSnapshot* floater_outfit_snapshot = LLFloaterSimpleSnapshot::findInstance();
if (floater_outfit_snapshot)
floater_outfit_snapshot->closeFloater(app_quitting);
if (gMenuHolder) gMenuHolder->hideMenus();
diff --git a/indra/newview/skins/default/xui/en/floater_simple_outfit_snapshot.xml b/indra/newview/skins/default/xui/en/floater_simple_snapshot.xml
index 5ece7b85d5..1e47a3b35d 100644
--- a/indra/newview/skins/default/xui/en/floater_simple_outfit_snapshot.xml
+++ b/indra/newview/skins/default/xui/en/floater_simple_snapshot.xml
@@ -7,7 +7,7 @@
can_close="true"
height="305"
layout="topleft"
- name="simple_outfit_snapshot"
+ name="simple_snapshot"
single_instance="true"
help_topic="snapshot"
save_rect="true"
diff --git a/indra/newview/llfloatersimpleoutfitsnapshot.cpp b/indra/newview/llfloatersimplesnapshot.cpp
index 703112a0fa..05625e6817 100644
--- a/indra/newview/llfloatersimpleoutfitsnapshot.cpp
+++ b/indra/newview/llfloatersimplesnapshot.cpp
@@ -1,6 +1,6 @@
/**
* @file llfloatersimpleoutfitsnapshot.cpp
* @brief Snapshot preview window for saving as an outfit thumbnail in visual outfit gallery
*
* $LicenseInfo:firstyear=2022&license=viewerlgpl$
* Second Life Viewer Source Code
@@ -26,37 +26,38 @@
#include "llviewerprecompiledheaders.h"
-#include "llfloatersimpleoutfitsnapshot.h"
+#include "llfloatersimplesnapshot.h"
#include "llfloaterreg.h"
#include "llimagefiltersmanager.h"
#include "llstatusbar.h" // can_afford_transaction()
#include "llnotificationsutil.h"
+#include "lloutfitgallery.h"
#include "llagentbenefits.h"
#include "llviewercontrol.h"
-LLSimpleOutfitSnapshotFloaterView* gSimpleOutfitSnapshotFloaterView = NULL;
+LLSimpleSnapshotFloaterView* gSimpleSnapshotFloaterView = NULL;
-const S32 OUTFIT_SNAPSHOT_WIDTH = 256;
-const S32 OUTFIT_SNAPSHOT_HEIGHT = 256;
+const S32 THUMBNAIL_SNAPSHOT_WIDTH = 256;
+const S32 THUMBNAIL_SNAPSHOT_HEIGHT = 256;
-static LLDefaultChildRegistry::Register<LLSimpleOutfitSnapshotFloaterView> r("simple_snapshot_outfit_floater_view");
+static LLDefaultChildRegistry::Register<LLSimpleSnapshotFloaterView> r("simple_snapshot_floater_view");
///----------------------------------------------------------------------------
-/// Class LLFloaterSimpleOutfitSnapshot::Impl
+/// Class LLFloaterSimpleSnapshot::Impl
///----------------------------------------------------------------------------
-LLSnapshotModel::ESnapshotFormat LLFloaterSimpleOutfitSnapshot::Impl::getImageFormat(LLFloaterSnapshotBase* floater)
+LLSnapshotModel::ESnapshotFormat LLFloaterSimpleSnapshot::Impl::getImageFormat(LLFloaterSnapshotBase* floater)
{
return LLSnapshotModel::SNAPSHOT_FORMAT_PNG;
}
-LLSnapshotModel::ESnapshotLayerType LLFloaterSimpleOutfitSnapshot::Impl::getLayerType(LLFloaterSnapshotBase* floater)
+LLSnapshotModel::ESnapshotLayerType LLFloaterSimpleSnapshot::Impl::getLayerType(LLFloaterSnapshotBase* floater)
{
return LLSnapshotModel::SNAPSHOT_TYPE_COLOR;
}
-void LLFloaterSimpleOutfitSnapshot::Impl::updateControls(LLFloaterSnapshotBase* floater)
+void LLFloaterSimpleSnapshot::Impl::updateControls(LLFloaterSnapshotBase* floater)
{
LLSnapshotLivePreview* previewp = getPreviewView();
updateResolution(floater);
@@ -68,14 +69,14 @@ void LLFloaterSimpleOutfitSnapshot::Impl::updateControls(LLFloaterSnapshotBase*
}
}
-std::string LLFloaterSimpleOutfitSnapshot::Impl::getSnapshotPanelPrefix()
+std::string LLFloaterSimpleSnapshot::Impl::getSnapshotPanelPrefix()
{
return "panel_outfit_snapshot_";
}
-void LLFloaterSimpleOutfitSnapshot::Impl::updateResolution(void* data)
+void LLFloaterSimpleSnapshot::Impl::updateResolution(void* data)
{
- LLFloaterSimpleOutfitSnapshot *view = (LLFloaterSimpleOutfitSnapshot *)data;
+ LLFloaterSimpleSnapshot *view = (LLFloaterSimpleSnapshot *)data;
if (!view)
{
@@ -83,8 +84,8 @@ void LLFloaterSimpleOutfitSnapshot::Impl::updateResolution(void* data)
return;
}
- S32 width = OUTFIT_SNAPSHOT_WIDTH;
- S32 height = OUTFIT_SNAPSHOT_HEIGHT;
+ S32 width = THUMBNAIL_SNAPSHOT_WIDTH;
+ S32 height = THUMBNAIL_SNAPSHOT_HEIGHT;
LLSnapshotLivePreview* previewp = getPreviewView();
if (previewp)
@@ -111,7 +112,7 @@ void LLFloaterSimpleOutfitSnapshot::Impl::updateResolution(void* data)
}
}
-void LLFloaterSimpleOutfitSnapshot::Impl::setStatus(EStatus status, bool ok, const std::string& msg)
+void LLFloaterSimpleSnapshot::Impl::setStatus(EStatus status, bool ok, const std::string& msg)
{
switch (status)
{
@@ -130,27 +131,27 @@ void LLFloaterSimpleOutfitSnapshot::Impl::setStatus(EStatus status, bool ok, con
}
///----------------------------------------------------------------re------------
-/// Class LLFloaterSimpleOutfitSnapshot
+/// Class LLFloaterSimpleSnapshot
///----------------------------------------------------------------------------
-LLFloaterSimpleOutfitSnapshot::LLFloaterSimpleOutfitSnapshot(const LLSD& key)
+LLFloaterSimpleSnapshot::LLFloaterSimpleSnapshot(const LLSD& key)
: LLFloaterSnapshotBase(key),
mOutfitGallery(NULL)
{
impl = new Impl(this);
}
-LLFloaterSimpleOutfitSnapshot::~LLFloaterSimpleOutfitSnapshot()
+LLFloaterSimpleSnapshot::~LLFloaterSimpleSnapshot()
{
}
-BOOL LLFloaterSimpleOutfitSnapshot::postBuild()
+BOOL LLFloaterSimpleSnapshot::postBuild()
{
getChild<LLUICtrl>("save_btn")->setLabelArg("[UPLOAD_COST]", std::to_string(LLAgentBenefitsMgr::current().getTextureUploadCost()));
childSetAction("new_snapshot_btn", ImplBase::onClickNewSnapshot, this);
- childSetAction("save_btn", boost::bind(&LLFloaterSimpleOutfitSnapshot::onSend, this));
- childSetAction("cancel_btn", boost::bind(&LLFloaterSimpleOutfitSnapshot::onCancel, this));
+ childSetAction("save_btn", boost::bind(&LLFloaterSimpleSnapshot::onSend, this));
+ childSetAction("cancel_btn", boost::bind(&LLFloaterSimpleSnapshot::onCancel, this));
mThumbnailPlaceholder = getChild<LLUICtrl>("thumbnail_placeholder");
@@ -183,7 +184,7 @@ BOOL LLFloaterSimpleOutfitSnapshot::postBuild()
const S32 PREVIEW_OFFSET_Y = 70;
-void LLFloaterSimpleOutfitSnapshot::draw()
+void LLFloaterSimpleSnapshot::draw()
{
LLSnapshotLivePreview* previewp = getPreviewView();
@@ -219,7 +220,7 @@ void LLFloaterSimpleOutfitSnapshot::draw()
impl->updateLayout(this);
}
-void LLFloaterSimpleOutfitSnapshot::onOpen(const LLSD& key)
+void LLFloaterSimpleSnapshot::onOpen(const LLSD& key)
{
LLSnapshotLivePreview* preview = getPreviewView();
if (preview)
@@ -235,12 +236,12 @@ void LLFloaterSimpleOutfitSnapshot::onOpen(const LLSD& key)
impl->setStatus(ImplBase::STATUS_READY);
}
-void LLFloaterSimpleOutfitSnapshot::onCancel()
+void LLFloaterSimpleSnapshot::onCancel()
{
closeFloater();
}
-void LLFloaterSimpleOutfitSnapshot::onSend()
+void LLFloaterSimpleSnapshot::onSend()
{
S32 expected_upload_cost = LLAgentBenefitsMgr::current().getTextureUploadCost();
if (can_afford_transaction(expected_upload_cost))
@@ -257,15 +258,15 @@ void LLFloaterSimpleOutfitSnapshot::onSend()
}
}
-void LLFloaterSimpleOutfitSnapshot::postSave()
+void LLFloaterSimpleSnapshot::postSave()
{
impl->setStatus(ImplBase::STATUS_WORKING);
}
// static
-void LLFloaterSimpleOutfitSnapshot::update()
+void LLFloaterSimpleSnapshot::update()
{
- LLFloaterSimpleOutfitSnapshot* inst = findInstance();
+ LLFloaterSimpleSnapshot* inst = findInstance();
if (inst != NULL)
{
inst->impl->updateLivePreview();
@@ -274,18 +275,18 @@ void LLFloaterSimpleOutfitSnapshot::update()
// static
-LLFloaterSimpleOutfitSnapshot* LLFloaterSimpleOutfitSnapshot::findInstance()
+LLFloaterSimpleSnapshot* LLFloaterSimpleSnapshot::findInstance()
{
- return LLFloaterReg::findTypedInstance<LLFloaterSimpleOutfitSnapshot>("simple_outfit_snapshot");
+ return LLFloaterReg::findTypedInstance<LLFloaterSimpleSnapshot>("simple_outfit_snapshot");
}
// static
-LLFloaterSimpleOutfitSnapshot* LLFloaterSimpleOutfitSnapshot::getInstance()
+LLFloaterSimpleSnapshot* LLFloaterSimpleSnapshot::getInstance()
{
- return LLFloaterReg::getTypedInstance<LLFloaterSimpleOutfitSnapshot>("simple_outfit_snapshot");
+ return LLFloaterReg::getTypedInstance<LLFloaterSimpleSnapshot>("simple_outfit_snapshot");
}
-void LLFloaterSimpleOutfitSnapshot::saveTexture()
+void LLFloaterSimpleSnapshot::saveTexture()
{
LLSnapshotLivePreview* previewp = getPreviewView();
if (!previewp)
@@ -310,10 +311,10 @@ void LLFloaterSimpleOutfitSnapshot::saveTexture()
/// Class LLSimpleOutfitSnapshotFloaterView
///----------------------------------------------------------------------------
-LLSimpleOutfitSnapshotFloaterView::LLSimpleOutfitSnapshotFloaterView(const Params& p) : LLFloaterView(p)
+LLSimpleSnapshotFloaterView::LLSimpleSnapshotFloaterView(const Params& p) : LLFloaterView(p)
{
}
-LLSimpleOutfitSnapshotFloaterView::~LLSimpleOutfitSnapshotFloaterView()
+LLSimpleSnapshotFloaterView::~LLSimpleSnapshotFloaterView()
{
}
@@ -1,6 +1,6 @@
/**
-* @file llfloatersimpleoutfitsnapshot.cpp
-* @brief Snapshot preview window for saving as an outfit thumbnail in visual outfit gallery
+* @file llfloatersimplesnapshot.cpp
+* @brief Snapshot preview window for saving as a thumbnail
*
* $LicenseInfo:firstyear=2022&license=viewerlgpl$
diff --git a/indra/newview/llfloatersimpleoutfitsnapshot.h b/indra/newview/llfloatersimplesnapshot.h
index cc9a6c5d1e..f9a1d9b9bf 100644
--- a/indra/newview/llfloatersimpleoutfitsnapshot.h
+++ b/indra/newview/llfloatersimplesnapshot.h
@@ -1,6 +1,6 @@
/**
* @file llfloatersimpleoutfitsnapshot.h
* @brief Snapshot preview window for saving as an outfit thumbnail in visual outfit gallery
*
* $LicenseInfo:firstyear=2022&license=viewerlgpl$
* Second Life Viewer Source Code
@@ -24,26 +24,27 @@
* $/LicenseInfo$
*/
-#ifndef LL_LLFLOATERSIMPLEOUTFITSNAPSHOT_H
-#define LL_LLFLOATERSIMPLEOUTFITSNAPSHOT_H
+#ifndef LL_LLFLOATERSIMPLESNAPSHOT_H
+#define LL_LLFLOATERSIMPLESNAPSHOT_H
#include "llfloater.h"
#include "llfloatersnapshot.h"
-#include "lloutfitgallery.h"
#include "llsnapshotlivepreview.h"
+class LLOutfitGallery;
+
///----------------------------------------------------------------------------
-/// Class LLFloaterSimpleOutfitSnapshot
+/// Class LLFloaterSimpleSnapshot
///----------------------------------------------------------------------------
-class LLFloaterSimpleOutfitSnapshot : public LLFloaterSnapshotBase
+class LLFloaterSimpleSnapshot : public LLFloaterSnapshotBase
{
- LOG_CLASS(LLFloaterSimpleOutfitSnapshot);
+ LOG_CLASS(LLFloaterSimpleSnapshot);
public:
- LLFloaterSimpleOutfitSnapshot(const LLSD& key);
- ~LLFloaterSimpleOutfitSnapshot();
+ LLFloaterSimpleSnapshot(const LLSD& key);
+ ~LLFloaterSimpleSnapshot();
BOOL postBuild();
void onOpen(const LLSD& key);
@@ -51,8 +52,8 @@ public:
static void update();
- static LLFloaterSimpleOutfitSnapshot* getInstance();
- static LLFloaterSimpleOutfitSnapshot* findInstance();
+ static LLFloaterSimpleSnapshot* getInstance();
+ static LLFloaterSimpleSnapshot* findInstance();
void saveTexture();
const LLRect& getThumbnailPlaceholderRect() { return mThumbnailPlaceholder->getRect(); }
@@ -75,12 +76,12 @@ private:
};
///----------------------------------------------------------------------------
-/// Class LLFloaterSimpleOutfitSnapshot::Impl
+/// Class LLFloaterSimpleSnapshot::Impl
///----------------------------------------------------------------------------
-class LLFloaterSimpleOutfitSnapshot::Impl : public LLFloaterSnapshotBase::ImplBase
+class LLFloaterSimpleSnapshot::Impl : public LLFloaterSnapshotBase::ImplBase
{
- LOG_CLASS(LLFloaterSimpleOutfitSnapshot::Impl);
+ LOG_CLASS(LLFloaterSimpleSnapshot::Impl);
public:
Impl(LLFloaterSnapshotBase* floater)
: LLFloaterSnapshotBase::ImplBase(floater)
@@ -108,7 +109,7 @@ private:
/// Class LLSimpleOutfitSnapshotFloaterView
///----------------------------------------------------------------------------
-class LLSimpleOutfitSnapshotFloaterView : public LLFloaterView
+class LLSimpleSnapshotFloaterView : public LLFloaterView
{
public:
struct Params
@@ -117,13 +118,13 @@ public:
};
protected:
- LLSimpleOutfitSnapshotFloaterView(const Params& p);
+ LLSimpleSnapshotFloaterView(const Params& p);
friend class LLUICtrlFactory;
public:
- virtual ~LLSimpleOutfitSnapshotFloaterView();
+ virtual ~LLSimpleSnapshotFloaterView();
};
-extern LLSimpleOutfitSnapshotFloaterView* gSimpleOutfitSnapshotFloaterView;
+extern LLSimpleSnapshotFloaterView* gSimpleOutfitSnapshotFloaterView;
-#endif // LL_LLFLOATERSIMPLEOUTFITSNAPSHOT_H
+#endif // LL_LLFLOATERSIMPLESNAPSHOT_H
@@ -1,6 +1,6 @@
/**
-* @file llfloatersimpleoutfitsnapshot.h
-* @brief Snapshot preview window for saving as an outfit thumbnail in visual outfit gallery
+* @file llfloatersimplesnapshot.h
+* @brief Snapshot preview window for saving as a thumbnail
*
* $LicenseInfo:firstyear=2022&license=viewerlgpl$